/****************************************************************
**
** Definition of Gantt class
**
** This software is released under the GPL General Public License,
** see COPYING for details.
**
****************************************************************/

#ifndef GANTT_H
#define GANTT_H

#include <qwidget.h>

class QPainter;
class QPrinter;
class QPrintDialog;
class QFile;
class QFileDialog;
class QTextStream;
class QString;
class QDate;


class Gantt : public QWidget
	{
	Q_OBJECT
	public:
		Gantt( char *filenamearg, QWidget *parent=0, const char *name=0 );
		
		const static int NUMTASKS = 100;  // max number of tasks to read
		const static int TEXTPIXY = 50;   // number of pixels for the header (y)
		const static int FONTSIZE = 10;   // task font size
		const static int SPACING = 25;    // vertical space between tasks
		struct task
			{
			int num;
			QString *type;
			QDate   *startdate;
			QDate   *enddate;
			int after;
			int during;
			QString *description;
			};
		task *tasks[NUMTASKS];
		int numtasks;          // current number of tasks read
		int textpixx;          // number of pixels for the description (x)
		int daypix;            // number of pixels between each day
		int fileisread;
		QDate *project_startdate;
		QString *header;
		QFile *file;
	public slots:
		void open();
		void print();
		void draw();
		void refresh();
		void changetextpix( int tpix );
		void changedaypix( int dpix );
	protected:
		void open( QFile *openfile );
		void readfile( QTextStream *t );
		void paint( QPainter *painter );
		void paintEvent( QPaintEvent *e );
		void painttask( QPainter *painter, int i );
		void paintmain( QPainter *painter, int i );
		void paintmile( QPainter *painter, int i );
		void painttaskbeginarrow( QPainter *painter, int i, int j );
		void painttaskendarrow( QPainter *painter, int i, int j );
		void paintmainbeginarrow( QPainter *painter, int i, int j );
		void paintmainendarrow( QPainter *painter, int i, int j );
		void paintmilebeginarrow( QPainter *painter, int i, int j );
		void paintmileendarrow( QPainter *painter, int i, int j );
	private:
	};

#endif // GANTT_H
